Bifrost
-------

Bifrost (pronounced bye-frost) is a set of Ansible playbooks that
automates the task of deploying a base image onto a set of known hardware using
ironic. It provides modular utility for one-off operating system deployment
with as few operational requirements as reasonably possible.

Team and repository tags:

.. image:: https://governance.openstack.org/tc/badges/bifrost.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

Use Cases
~~~~~~~~~

* Installation of ironic in standalone/noauth mode without other OpenStack
  components.
* Deployment of an operating system to a known pool of hardware as
  a batch operation.
* Testing and development of ironic in a standalone use case.

Documentation
~~~~~~~~~~~~~

Bifrost's documentation can be found at the
`OpenStack documentation site <https://docs.openstack.org/bifrost/latest>`_.

The project source code repository is located at:
  https://git.openstack.org/cgit/openstack/bifrost/

Bugs can be filed in storyboard:
  https://storyboard.openstack.org/#!/project/941

Release notes
~~~~~~~~~~~~~
https://docs.openstack.org/releasenotes/bifrost/
